Stan Math Library: stan/math/fwd/scal/fun/falling_factorial.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

falling_factorial.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_SCAL_FUN_FALLING_FACTORIAL_HPP
2 #define STAN_MATH_FWD_SCAL_FUN_FALLING_FACTORIAL_HPP
3
4 #include <stan/math/fwd/core.hpp>
5
6 #include <stan/math/prim/scal/fun/falling_factorial.hpp>
7 #include <boost/math/special_functions/digamma.hpp>
8
9 namespace stan {
10
11 namespace math {
12
13 template<typename T>
14 inline fvar<T>
15 falling_factorial(const fvar<T>& x, const fvar<T>& n) {
16 using stan::math::falling_factorial;
17 using boost::math::digamma;
18
19 T falling_fact(falling_factorial(x.val_, n.val_));
20 return fvar<T>(falling_fact,
21 falling_fact
22 * (digamma(x.val_ + 1) - digamma(x.val_ - n.val_ + 1))
23 * x.d_
24 + falling_fact
25 * digamma(x.val_ - n.val_ + 1) * n.d_);
26 }
27
28 template<typename T>
29 inline fvar<T>
30 falling_factorial(const fvar<T>& x, const double n) {
31 using stan::math::falling_factorial;
32 using boost::math::digamma;
33
34 T falling_fact(falling_factorial(x.val_, n));
35 return fvar<T>(falling_fact,
36 falling_fact
37 * (digamma(x.val_ + 1) - digamma(x.val_ - n + 1))
38 * x.d_);
39 }
40
41 template<typename T>
42 inline fvar<T>
43 falling_factorial(const double x, const fvar<T>& n) {
44 using stan::math::falling_factorial;
45 using boost::math::digamma;
46
47 T falling_fact(falling_factorial(x, n.val_));
48 return fvar<T>(falling_fact,
49 falling_fact
50 * digamma(x - n.val_ + 1) * n.d_);
51 }
52 }
53 }
54 #endif
falling_factorial.hpp
core.hpp
stan::math::fvar::d_
T d_
Definition: fvar.hpp:15
stan
Definition: log_sum_exp.hpp:8
stan::math::fvar::val_
T val_
Definition: fvar.hpp:14
stan::math::falling_factorial
fvar< T > falling_factorial(const fvar< T > &x, const fvar< T > &n)
Definition: falling_factorial.hpp:15
stan::math::fvar
Definition: fvar.hpp:13
stan::math::digamma
fvar< T > digamma(const fvar< T > &x)
Definition: digamma.hpp:16

[ Stan Home Page ] © 2011–2016, Stan Development Team.